Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(49)

Unified Diff: pkg/compiler/lib/src/ssa/codegen.dart

Issue 2306203002: Rename HForeignNew -> HCreate (Closed)
Patch Set: comments and reformat Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/compiler/lib/src/ssa/builder.dart ('k') | pkg/compiler/lib/src/ssa/codegen_helpers.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/compiler/lib/src/ssa/codegen.dart
diff --git a/pkg/compiler/lib/src/ssa/codegen.dart b/pkg/compiler/lib/src/ssa/codegen.dart
index 0d6376ecd83102490e74afed5f99d485b0b4c269..abd0314aa45d4ca41cd3399deef69fe4e94f619a 100644
--- a/pkg/compiler/lib/src/ssa/codegen.dart
+++ b/pkg/compiler/lib/src/ssa/codegen.dart
@@ -1931,14 +1931,13 @@ class SsaCodeGenerator implements HVisitor, HBlockInformationVisitor {
registerForeignTypes(node);
}
- visitForeignNew(HForeignNew node) {
+ visitCreate(HCreate node) {
js.Expression jsClassReference =
backend.emitter.constructorAccess(node.element);
List<js.Expression> arguments = visitArguments(node.inputs, start: 0);
push(new js.New(jsClassReference, arguments)
.withSourceInformation(node.sourceInformation));
- registerForeignTypes(node);
- // We also use ForeignNew to instantiate closure classes that belong to
+ // We also use HCreate to instantiate closure classes that belong to
// function expressions. We have to register their use here, as otherwise
// code for them might not be emitted.
if (node.element.isClosure) {
« no previous file with comments | « pkg/compiler/lib/src/ssa/builder.dart ('k') | pkg/compiler/lib/src/ssa/codegen_helpers.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698